<?php
use Required\DynamicSyncDataController;

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Plugin_Name
 * @subpackage Plugin_Name/admin
 * @author     Your Name <email@example.com>
 */
class DynamicSync_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/dynamicsync-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Plugin_Name_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Plugin_Name_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/dynamicsync-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function dynamicsyncSettingsPage(){
		$page_title = "DynamicSync Settings";
		$menu_title = "DynamicSync";
		$capability = "manage_options";
		$menu_slug = "dynamicsync-wp-v2";
		$function = array($this, 'showDSSettings');
		$icon_url = '';
		$position = "100";

		add_menu_page( $page_title, $menu_title, $capability, $menu_slug, $function, $icon_url, $position );

	}

	public function dynamicsyncInstructionsPage(){
		$parent_slug = "dynamicsync-wp-v2";
		$page_title = "DynamicSync Instructions";
		$menu_title = "Instructions";
		$capability = "manage_options";
		$menu_slug = "dynamicsync-instructions";
		$function = array($this, 'showDSInstructions');
		add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);
	}

	public function dynamicsyncStylesPage(){
		$parent_slug = "dynamicsync-wp-v2";
		$page_title = "DynamicSync Styles";
		$menu_title = "Styles";
		$capability = "manage_options";
		$menu_slug = "dynamicsync-styles";
		$function = array($this, 'showDSStyles');
		add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);
	}

    public function dynamicsyncMappingPage(){
        $parent_slug = "dynamicsync-wp-v2";
        $page_title = "DynamicSync Mapping";
        $menu_title = "Mapping";
        $capability = "manage_options";
        $menu_slug = "dynamicsync-mapping";
        $function = array($this, 'showDSMapping');
        add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);
    }

	public function dynamicsyncShortcodeBuilder(){
		add_meta_box('dsBuilderMetabox', __('DynamicSync Shortcode Builder'), [&$this, 'dsMetabox'], 'page', 'normal' );

	}

	public function showDSSettings($args){
        wp_enqueue_script( 'ds-admin-settings-js', plugin_dir_url( __FILE__ ) . 'js/dynamicsync-admin.js', array( 'jquery' ), false );
		wp_enqueue_style( 'ds-admin-settings-css', plugin_dir_url( __FILE__ ) . 'css/dynamicsync-admin.css', array());

		$dynamicSync = new DynamicSyncDataController();

        if($_POST){
            $apiKey = $_POST['apiKey'];
            $formUrl = $_POST['regFormUrl'];
            $settings = $dynamicSync->updateSettings($apiKey,$formUrl);
        }
        else{
            $settings = $dynamicSync->getSettings();
        }
        
		include dirname(__FILE__).'/partials/dynamicsync-settings-admin-display.php';
	}

	public function showDSInstructions(){

		wp_enqueue_script( 'ds-admin-settings-js', plugin_dir_url( __FILE__ ) . 'js/dynamicsync-admin.js', array( 'jquery' ), false );
		wp_enqueue_style( 'ds-admin-settings-css', plugin_dir_url( __FILE__ ) . 'css/dynamicsync-admin.css', array());
		
		include dirname(__FILE__).'/partials/dynamicsync-instructions-admin-display.php';
	}

	public function showDSStyles(){


		$dynamicSync = new DynamicSyncDataController();

        if($_POST){
            $datesListCSSField = $_POST['datesListCSSField'];
            $eventDatesListCSSField = $_POST['eventDatesListCSSField'];
            $fullCalendarCSSField = $_POST['fullCalendarCSSField'];
            $tableCSSField = $_POST['tableCSSField'];
            $customCSSField = $_POST['customCSSField'];
            
            $settings = $dynamicSync->updateStyles($datesListCSSField,$eventDatesListCSSField,$fullCalendarCSSField,$tableCSSField,$customCSSField);
        }
        else{
            $settings = $dynamicSync->getSettings();
        }

		wp_enqueue_script( 'ds-admin-settings-js', plugin_dir_url( __FILE__ ) . 'js/dynamicsync-admin.js', array( 'jquery' ), false );
		wp_enqueue_style( 'ds-admin-settings-css', plugin_dir_url( __FILE__ ) . 'css/dynamicsync-admin.css', array());
		
		include dirname(__FILE__).'/partials/dynamicsync-styles-admin-display.php';
	}

    public function showDSMapping()
    {
        $dynamicSync = new DynamicSyncDataController();

        if($_POST){
            
        }
        else{
            $settings = $dynamicSync->getSettings();
        }

        wp_enqueue_script( 'ds-admin-settings-js', plugin_dir_url( __FILE__ ) . 'js/dynamicsync-admin.js', array( 'jquery' ), false );
        wp_enqueue_style( 'ds-admin-settings-css', plugin_dir_url( __FILE__ ) . 'css/dynamicsync-admin.css', array());
        
        include dirname(__FILE__).'/partials/dynamicsync-mapping-display.php';
    }

	public function dsMetabox()
    {
    	$dynamicSync = new DynamicSyncDataController();
		$settings = $dynamicSync->getSettings();


        global $post;
        $eventJSON = $dynamicSync->GetEventData();
        $pages = $dynamicSync->GetWPPages();
        //wp_enqueue_script( 'jqueryJS', 'https://ajax.googleapis.com/ajax/libs/jquery/1.12.4/jquery.min.js' );
        wp_enqueue_script( 'ds-admin-metabox-js', plugin_dir_url( __FILE__ ) . 'js/dynamicsync-metabox.js', array( 'jquery' ), false );
		wp_enqueue_style( 'ds-admin-metabox-css', plugin_dir_url( __FILE__ ) . 'css/dynamicsync-metabox.css', array());

        ?>
        <input type="hidden" name="event_noncename" value="<?php echo wp_create_nonce( plugin_basename(__FILE__) ) ?>" />
        <script>
            var objPages = <?php echo $pages ?>;
            var objEvents = <?php echo $eventJSON ?>;
            var apiKey = "<?php echo $settings->api_key ?>";
        </script>
        <div class="ds-wrap">
            <div id="dsErrorStatus">
                <div>Remember the hidden Event Date ID</div>
            </div>
            <div class="ds-nav-layout">
                <div class="ds-tab-active" id="navEventData">Calendar Layout</div>
                <div id="navFields">Events Info Fields</div>
                <div id="navSelect">Date Selection</div>
                <div id="navMap">Map</div>
                <div id="navOther">Registration</div>
                <?php /* <div id="navOther">Other</div> */ ?>
            </div>
            <div class="ds-content-tab navEventData ds-block ds-tab-active">
                <div class="ds-metabox-layout">
                    <div data-id="Standard">Events Date List</div>
                    <div data-id="dates_list">Side Bar</div>
                    <div data-id="table">Table</div>
                    <div data-id="calendar">Calendar</div>
                    <!--<div class="ds-metabox-layout" data-id="event_info">Event Info</div>-->
                </div>
                <div class="ds-event-details ds-block">
                    <div class="ds-input-container">
                        <div class="dsEventPlus dsAddCalendarEventId" data-id="calendarEventId"></div>
                        <input placeholder="Event ID" type="text" id="ds-event-id-input" name="ds-event-id-input" value="" class="ds-input dsEventIdTextBox" />
                        <div class="ds-hover-event-id ds-hover-block" id="calendarEventId"></div>
                    </div>
                    <div class="ds-input-container">
                        <div class="dsEventPlus dsPagesEventListRegForm" data-id="wpPageRegForm"></div>
                        <input placeholder="Registration Form URL" type="text" id="ds-reg-form-input" name="ds-reg-form-input" value="" class="ds-input" />
                        <div class="ds-hover-page-event-list ds-hover-block" id="wpPageRegForm"></div>
                    </div>
                    <div class="ds-input-container">
                        <div class="dsEventPlus dsPagesEventListEventFull" data-id="wpPageEventFull"></div>
                        <input placeholder="Event Full URL" type="text" id="ds-event-full-input" name="ds-event-full-input" value="" class="ds-input" />
                        <div class="ds-hover-page-event-full ds-hover-block" id="wpPageEventFull"></div>
                    </div>
                </div>
                <div class="ds-event-calendar-image">
                    
                </div>
            </div>
            <div class="ds-content-tab ds-block navFields">
                <div class="ds-event-details ds-block">
                    <div class="ds-input-container">
                        <div class="dsEventPlus dsAddEventInfo" data-id="infoEventId"></div>
                        <input placeholder="Event ID" type="text" id="ds-field-event-id-input" name="ds-field-event-id-input" value="" class="ds-input dsEventIdTextBox" />
                        <div class="ds-hover-event-info ds-hover-block" id="infoEventId"></div>
                    </div>
                    <div class="ds-input-container">
                        <input placeholder="Sequence Number" type="number" id="ds-field-event-seq-no-input" name="ds-field-event-seq-no-input" value="" class="ds-input dsEventIdTextBox" />
                    </div>
                    <div class="ds-input-container">
                        <select class="ds-input" id="ds-field-event-info-select">
                            <option value="event_date_id" >Event Date ID</option>
                            <option value="title" selected>Title</option>
                            <option value="description">Description</option>
                            <option value="start_date">Start Date</option>
                            <option value="end_date">End Date</option>
                            <option value="start_time">Start Time</option>
                            <option value="end_time">End Time</option>
                            <option value="timezone">Timezone</option>
                            <option value="pretty_time">Pretty Time</option>
                            <option value="statusLabel">Status</option>
                            <option value="venue_name">Venue Name</option>
                            <option value="venue_address">Venue Address</option>
                            <option value="contact_person">Contact Person</option>
                            <option value="contact_number">Contact Number</option>
                            <option value="price">Price</option>
                            <option value="user1">User Field 1</option>
                            <option value="user2">User Field 2</option>
                            <option value="user3">User Field 3</option>
                            <option value="user4">User Field 4</option>
                        </select>
                    </div>
                    <div class=""> <div class="dsStaticEventPlus dsAdvancedTitle" data-id="infoEventId"></div>Advanced</div>
                    <div class="dsEventInfoAdvanced">
                        <input placeholder="Date Format" type="text" id="ds-event-info-date-format" name="ds-event-info-date-format" value="" class="ds-input dsEventIdTextBox" />
                        <br>
                        <input placeholder="Prepend" type="text" id="ds-event-info-prepend" name="ds-event-info-prepend" value="" class="ds-input dsEventIdTextBox" />
                        <br>
                        <input placeholder="Append" type="text" id="ds-event-info-append" name="ds-event-info-append" value="" class="ds-input dsEventIdTextBox" />
                        <br>
                        <input placeholder="No Event Message" type="text" id="ds-event-info-no-event-text" name="ds-event-info-no-event-text" value="" class="ds-input dsEventIdTextBox" /> Conditional Output
                        <input type="checkbox" id="ds-event-info-conditional" name="ds-event-info-conditional" value="conditionalOutput" />
                        <div class="ds-conditionalable disabled">
                            Message if true <input type="text" id="ds-event-info-trueoutput" name="ds-event-info-trueoutput" value="" class="ds-smaller-input" />
                        </div>
                        <div class="ds-conditionalable disabled">
                            Message if false <input type="text" id="ds-event-info-falseoutput" name="ds-event-info-falseoutput" value="" class="ds-smaller-input" />
                        </div>
                        <input placeholder="Filter" type="text" id="ds-event-info-filter" name="ds-event-info-filter" value="" class="ds-input dsEventIdTextBox" />
                        
                    </div>
                </div>
                <div class="ds-shortcode-text">
                    <!-- <p>Display the event info</p> -->
                </div>
            </div>
            <div class="ds-content-tab navSelect">
                <div class="ds-date-selectors-layout">
                    <div data-id="dateSelector">Date Selector</div>
                    <div data-id="datePicker">Date Picker</div>
                </div>
                <div class="ds-event-details ds-block">
                    
                    <div class="ds-input-container">
                        <div class="dsEventPlus dsAddSelectEvent" data-id="selectEventId"></div>
                        <input placeholder="Event ID" type="text" id="ds-select-event-id-input" name="ds-select-event-id-input" value="" class="ds-input dsEventIdTextBox" />
                        <div class="ds-hover-select-events ds-hover-block" id="selectEventId"></div>
                    </div>
                    <div class="ds-input-container datePicker hidden">
                        <input placeholder="Date Picker Field ID" type="text" id="ds-date-picker-input" name="ds-date-picker-input" value="" class="ds-input dsEventIdTextBox" />
                    </div>
                    <div class="ds-input-container datePicker hidden">
                        <input placeholder="Event Date ID Field" type="text" id="ds-picker-event-date-id-field-input" name="ds-picker-event-date-id-field-input" value="" class="ds-input dsEventIdTextBox" />
                    </div>
                    <div class="ds-input-container dateSelector">
                        <div class="ds-select-field-wrapper">
                        <input placeholder="Event Field" type="text" id="ds-select-event-field" name="ds-select-event-field" value="" class="ds-input dsEventIdTextBox" />
                        <button type="button" class="ds-select-field-button">+</button>
                            <ul class="ds-select-fields" id="ds-field-event-info-select">
                                <li data-id="title">Title</li>
                                <li data-id="start_date">Start Date</li>
                                <li data-id="end_date">End Date</li>
                                <li data-id="pretty_time">Pretty Time</li>
                                <li data-id="venue_name">Venue Name</li>
                                <li data-id="price">Price</li>
                                <li data-id="user1">User Field 1</li>
                                <li data-id="user2">User Field 2</li>
                                <li data-id="user3">User Field 3</li>
                                <li data-id="user4">User Field 4</li>
                            </ul>
                        </div>
                    </div>
                </div>
                <div class="ds-date-selectors-image">
                    
                </div>
            </div>
            <div class="ds-content-tab navMap">
                <div class="ds-event-details ds-block">
                    <div class="ds-input-container">
                        <div class="dsEventPlus dsAddEventMap" data-id="mapEventId"></div>
                        <input placeholder="Event ID" type="text" id="ds-map-event-id-input" name="ds-map-event-id-input" value="" class="ds-input dsEventIdTextBox" />
                        <div class="ds-hover-map-events ds-hover-block" id="mapEventId"></div>
                    </div>
                    <div class="ds-input-container">
                        <input placeholder="Sequence Number" type="number" min="0" max="10" id="ds-map-seq-no" name="ds-map-seq-no" value="" class="ds-input dsEventIdTextBox" />
                    </div>
                    <div class="ds-input-container">
                        <input placeholder="Width" type="text" id="ds-map-width" name="ds-map-width" value="" class="ds-input dsEventIdTextBox" />
                    </div>
                    <div class="ds-input-container">
                        <input placeholder="Height" type="text" id="ds-map-height" name="ds-map-height" value="" class="ds-input dsEventIdTextBox" />
                    </div>
                </div>
                <div class="ds-shortcode-image">
                    <div class="map-img"><div>Example:</div></div>
                </div>
            </div>
            <div class="ds-content-tab ds-block navOther">
                <div class="ds-other-layout">
                    <div data-id="eventDateIdScript">Event Date ID Script</div>
                </div>
                <div class="ds-event-details ds-block">
                    <input placeholder="Hidden Field" type="text" id="ds-event-script-hidden-field" name="ds-event-script-hidden-fields" value="inf_custom_EventDateId" class="ds-input dsEventIdTextBox" />
                </div>
            </div>
            <div class="ds-output ds-block">
                <textarea class="ds-output-shortcode" id="ds-metabox-layout" readonly></textarea><br>
                <button type="button" id="ds-output-button">Paste Shortcode</button>
                <button type="button" onclick="checkFormHasEventDateId()" class="hidden">Check</button>
            </div>
        </div>
        <?php
    }
}
