<?php
namespace Required;
use DynamicSync\DynamicSync;
use Required\DynamicSyncSettings;

class DynamicSyncDataController extends DynamicSyncSettings{
	protected $urlParameters = array();
	protected $eventDates = array();
	protected $groupedEvents = array();
	protected $filteredEvents = array();
	protected $events = array();
	protected $params;

	public function __construct(){
		$this->loadDb();
	}

	public function getSettings(){
		return $this->settings;
	}

	public function load(){
		//if(isNoApi()) exit();

		$dynamicSync = new DynamicSync($this->settings->api_key);

		$filter = array(
		    'key' => 'status',
		    'compare' => '==',
		    'value' => '1'
		);

	    $eventDates = $dynamicSync->getEventDates('',$filter);
	    $events = array();

		foreach ($eventDates as $ed => $eventDate) {
		    $event_date_data = $eventDate->getEventDateData();
		    $events[] = $event_date_data;
		}
		return $events;
	}

	public function GetEventData(){
        $dynamicSync = new DynamicSync($this->settings->api_key);

        $events = $dynamicSync->getEvents();
        $json = array();

        foreach($events as $key => $event){
            $event_data = $event->getEventData();

            $eventDates = $dynamicSync->getEventDates($event_data['guid']);
            $eventDatesArray = array();
			$isActive = 0;
			
            foreach($eventDates as $i=>$eventDate){
                $event_date_data = $eventDate->getEventDateData();
                if($event_date_data['status'] == '1')
                	$isActive = 1;
				$eventDatesArray[$i]['StartDate'] = date('Y-m-d H:i:s', strtotime($event_date_data['start_date']) + (60 * 60 * $event_date_data['timezone']));
				$eventDatesArray[$i]['EndDate'] = date('Y-m-d H:i:s', strtotime($event_date_data['end_date']) + (60 * 60 * $event_date_data['timezone']));
				$eventDatesArray[$i]['EventID'] = $event_date_data['eventId'];
				$eventDatesArray[$i]['Title'] = $event_date_data['title'];
				$eventDatesArray[$i]['EventDateID'] = $event_date_data['guid'];
				$eventDatesArray[$i]['Timezone'] = $event_date_data['timezone'];
				$eventDatesArray[$i]['Status'] = $event_date_data['status'];
				$eventDatesArray[$i]['StatusLabel'] = $event_date_data['statusLabel'];
            }
			
			$json[$key]['EventID'] = $event_data['guid'];
			$json[$key]['Title'] = $event_data['title'];
			$json[$key]['Status'] = $isActive;
			$json[$key][] = $eventDatesArray;
			
        }

        return json_encode($json);
    }

	public function get_url_params() {
		$query = null;
		$urlParams = "";
		$request = parse_url($_SERVER['REQUEST_URI']);
		if(isset($request['query']))
			$query = $request['query'];
		else
			$query = $_SERVER['QUERY_STRING'];
		parse_str($query, $urlParams);

		$this->urlParameters = $urlParams;
	}

	public function addUrlParams($event) {
		// Add the other url parameters
		$urlParams = "";
		$first = true;
		if(!empty($this->settings->eventIdField)) {
			$first ? $urlParams .= "?" : $urlParams .= "&";
			$first = false;
			$urlParams .= $this->settings->eventIdField."=".$event['eventId'];
		}
		if(!empty($this->settings->eventDateIdField)) {
			$first ? $urlParams .= "?" : $urlParams .= "&";
			$first = false;
			$urlParams .= $this->settings->eventDateIdField."=".$event['guid'];
		}
		if(!empty($this->settings->eventNameField)) {
			$first ? $urlParams .= "?" : $urlParams .= "&";
			$first = false;
			$urlParams .= $this->settings->eventNameField."=".urlencode($event['title']);
		}
		if(!empty($this->settings->eventDateField)) {
			$first ? $urlParams .= "?" : $urlParams .= "&";
			$first = false;
			$urlParams .= $this->settings->eventDateField."=".urlencode($event['start_date']);
		}
		return $urlParams;
	}

	

	protected function load_events($key, $status = 'Confirmed', $reload = false){
		if(!$reload && !empty($this->eventDates)) {
			return true;
		}
		if(empty($key)){
			$key = $this->settings->api_key;
		}
		$dynamicSync = new DynamicSync($key);

		$filter = array(
		    'key' => 'statusLabel',
		    'compare' => '==',
		    'value' => $status
		);

		$evs = $dynamicSync->getEvents();
		$es = array();

		foreach ($evs as $ev) {
		    $event_data = $ev->getEventData();
		    $es[] = $event_data;
		}

	    $eventDates = $dynamicSync->getEventDates('',$filter);
	    $events = array();

		foreach ($eventDates as $ed => $eventDate) {
		    $event_date_data = $eventDate->getEventDateData();
		    $event_date_data = $this->handleEvent($event_date_data);
		    $event_date_data['eventTitle'] = $this->getEventTitle($event_date_data['eventId'],$es);
		    $events[] = $event_date_data;
		}

		

		// Set the global event dates array
		$this->eventDates = $events;
		$this->events = $es;
		return true;
	}

	protected function getEventTitle($eventId,$events){
		foreach($events as $event){
			if($event['guid'] == $eventId) return $event['title'];
		}
		return '';
	}

	protected function handleEvent($event){
		$event['soldOut'] = 0;
		$event['start_date']= date("Y-m-d H:i", strtotime($event['start_date']) + ($event['timezone'] * 60 * 60));
		$event['end_date']	= date("Y-m-d H:i", strtotime($event['end_date']) + ($event['timezone'] * 60 * 60));
		
		if(isset($event['max_attendees'])) {
			$placesLeft = $event['max_attendees'] - $event['num_attendees'];
			$event['placesLeft'] = $placesLeft;
			
			if($placesLeft <= 0) {
				$event['soldOut'] = 1;
				$event['regFormUrl'] = '';
				$event['url']	= '';
			}
		}

		if($this->isImage($event['user1']))
			$event['isImage'] = true;
		else
			$event['isImage'] = false;
		
		return $event;
	}

	public function applyParamsEvent($event){
		$event['s_date'] = strftime($this->params['dateformat'], strtotime($event['start_date']));
		$event['e_date'] = strftime($this->params['dateformat'], strtotime($event['end_date']));
		$event['s_time'] = date($this->params['timeformat'], strtotime($event['start_date']));
		$event['e_time'] = date($this->params['timeformat'], strtotime($event['end_date']));

		if(isset($event['placesLeft'])){
			if($event['placesLeft'] <= $this->params['lowwarningthreshold'] && $event['placesLeft'] > 0) {
				$event['lowWarning'] = 1;
			}
		}

		if(isset($this->params['registrationurlfield']) && isset($event[$this->params['registrationurlfield']])){
			$event['regFormUrl'] = $event[$this->params['registrationurlfield']];
			$event['regParams'] = $this->addUrlParams($event);
			$event['url']	= $event['regFormUrl'].$event['regParams'];

		}
		else if(!empty($this->params['eventfullurl']) && $event['soldOut']){
			$event['soldOut'] = 0;
			$event['regFormUrl'] = $this->params['eventfullurl'];
			$event['regParams'] = $this->addUrlParams($event);
			$event['url']	= $event['regFormUrl'].$event['regParams'];
		}
		else {
			$event['regFormUrl'] = $this->params['regFormUrl'];
			$event['regParams'] = $this->addUrlParams($event);
			$event['url']	= $event['regFormUrl'].$event['regParams'];
		}

		return $event;
	}

	protected function handleEventParams($params){
		if(empty($params['eventid']) && !empty($params['eventId'])) $params['eventid'] = $params['eventId'];
		if(empty($params['datedescription']) && !empty($params['dateDescription'])) $params['datedescription'] = $params['dateDescription'];
		if(empty($params['registerformurl']) && !empty($params['registerFormUrl'])) $params['registerformurl'] = $params['registerFormUrl'];
		if(empty($params['registrationurlfield']) && !empty($params['registrationUrlField'])) $params['registrationurlfield'] = $params['registrationUrlField'];
		if(!empty($params['registerformurl'])) $regFormUrl = $params['registerformurl']; else $regFormUrl = $this->settings->regFormUrl;
		if(empty($params['enddate'])) $params['enddate'] = null;
		
		$arrUrl = parse_url($regFormUrl);
		if(empty($arrUrl['query'])) $params['regFormUrl'] = $regFormUrl; else $params['regFormUrl'] = $arrUrl['scheme']."://".$arrUrl['host'].$arrUrl['path'];

		if(!empty($params['filter'])) {
			$strFilter = $params['filter'];
			$expFilter = explode("=", $strFilter);
			$params['arrFilter'] = array('field' => $expFilter[0], 'filter' => $expFilter[1]);
		} else {
			$params['arrFilter'] = array();
		}
		switch($params['setlocale']){
			case "spanish":
			case "Spanish":
			case "espanol":
			case "Espanol":
			case "esp":
			case "ESP":
				setlocale(LC_ALL, "es_ES@euro","es_ES","esp");
				break;
			case "german":
			case "German":
			case "deutsche":
			case "Deutsche":
			case "de":
			case "DE":
				setlocale(LC_ALL, 'de_DE@euro', 'de_DE', 'deu_deu');
				break;
			case "french":
			case "French":
			case "français":
			case "Français":
			case "francais":
			case "Francais":
			case "fr":
			case "FR":
				setlocale(LC_ALL, 'fr_FR@euro','fr_FR','fra');
				break;
			case "italian":
			case "Italian":
			case "italiano":
			case "Italiano":
			case "it":
			case "IT":
				setlocale(LC_ALL, 'it_IT@euro','it_IT.UTF-8','it');
				break;
		}
		$params['header']['title'] = 'Title';
		$params['header']['date'] = 'Date';
		$params['header']['time'] = 'Time';
		$params['header']['venue'] = 'Venue';

		$params['fields'] = explode(",",$params['fields']);

		if(!empty($params['headers'])){
			$headers = explode(",",$params['headers']);
			foreach($headers as $header){
				$h = explode("=",$header);
				$array = array($h[0] => $h[1]);
			
				switch($h[0]){
					case "title":
					case "Title":
						$params['header']['title'] = $h[1];
						break;
					case "date":
					case "Date":
						$params['header']['date'] = $h[1];
						break;
					case "time":
					case "Time":
						$params['header']['time'] = $h[1];
						break;
					case "Venue":
					case "venue":
						$params['header']['venue'] =  $h[1];
						break;
				}
			}
		}
		if(empty($params['registerbtn'])) $params['registerbtn'] = "Register Now";
		return $params;
	}

	protected function isImage($url = "") {
		$supported_image = array('gif','jpg','jpeg','png');
		$ext = strtolower(pathinfo($url, PATHINFO_EXTENSION)); // Using strtolower to overcome case sensitive
		return in_array($ext, $supported_image);
	}	

	protected function eventIsSoldOut( $event )
	{
		$max_attendees = $event['max_attendees'];
		$num_attendees = $event['num_attendees'];

		if ( empty( $max_attendees ) )	
			$max_attendees = '0';
		if ( empty( $num_attendees ) )
			$num_attendees = '0';
		
		//if not unlimited
		if ( (int) $max_attendees > 0 ){
			//get remaining attendees/tickets
			$attendees_left = (int) $max_attendees - (int) $num_attendees;

			//if less than zero, event is full
			if ( $attendees_left <= 0 ){
				
				return true;
			}
			else{

				return false;
			}
		}
		else
			return false;
	}

	protected function findEvent($atts) {
		// attributes
		if(empty($atts['eventseqno'])) {
			$atts['eventseqno'] = 0;
		}
		
		// Event Date ID will become the filter if specified
		// URL Event Date ID
		if((in_array("urleventdateid", $atts, true) || in_array("urlEventDateId", $atts, true) || in_array("UrlEventDateId", $atts, true)) && !array_key_exists('eventdateid', $atts)) {
			$this->get_url_params();

			$urleventdateid = $this->options['reg_form_event_date_id_field'];
		
			if(!empty($this->urlParameters[$urleventdateid])) {
				$atts['filter'] = "guid=".$this->urlParameters[$urleventdateid];
			}
		}
		
		// Event Date ID is specified
		if(array_key_exists('eventdateid', $atts)) {
			$atts['filter'] = "guid=".$atts['eventdateid'];
		}
		
		// URL Event ID Specified
		if((in_array("urleventid", $atts, true) || in_array("UrlEventId", $atts, true) || in_array("urlEventId", $atts, true)) && !array_key_exists('eventid', $atts)) {
			$this->get_url_params();

			$urleventid = $this->options['reg_form_event_id_field'];

			if(!empty($this->urlParameters[$urleventid])) {
				$atts['eventid'] = $this->urlParameters[$urleventid];
			}
		}
				
		// Filter is spcified
		if(!empty($atts['filter'])) {
			$strFilter = str_replace(' ', '', $atts['filter']);
			$expFilter = explode("=", $strFilter);
			$arrFilter = array('field' => $expFilter[0], 'filter' => $expFilter[1]);
		} else {
			$arrFilter = array();
		}

		// load the events
		if($this->load_events($this->settings->api_key)) {
			if(array_key_exists('eventid', $atts)) {
				$this->select_events($atts['eventid']);
			}				
			$this->filter_events($this->eventDates, $arrFilter);
			$this->group_events($this->filteredEvents);
				
		}

		if((count($this->groupedEvents) > 0) && ($atts['eventseqno'] < count($this->groupedEvents))) {
			$event = $this->groupedEvents[$atts['eventseqno']];
			return $event;
		} else {
			return false;
		}
	}

	protected function filter_events($eventDates, $filter) {
		// Apply Filter if required
		$this->filteredEvents = array();
		if(!empty($filter)) {
			foreach($eventDates as $eventDate) {
				if(!empty($filter['filter']))
					if(strpos($eventDate[$filter['field']], $filter['filter']) !== false) {
						$this->filteredEvents[] = $eventDate;
					}
			}
		} else {
			$this->filteredEvents = $eventDates;
		}
		return true;
	}

	protected function group_events($eventDates, $group="") {
		if(empty($eventDates)) {
			return false;
		}
		
		// Reset the group events array
		$this->groupedEvents = array();
		switch($group) {
			case 'month':
				foreach($eventDates as $event) {
					$month = date('F Y', strtotime($event['start_date']));
					$this->groupedEvents[$month][] = $event;
				}
				break;
			case 'eventId':
				// By default, events will be grouped by event type
				foreach($eventDates as $event) {
					$this->groupedEvents[$event['eventId']][] = $event;
				}
				break;

			default:
				$this->groupedEvents = $eventDates;
				break;
		}
		return true;
	}

	public function GetWPPages(){
		$args = array(
            'sort_order' => 'asc',
            'sort_column' => 'post_title',
            'hierarchical' => 1,
            'exclude' => '',
            'include' => '',
            'meta_key' => '',
            'meta_value' => '',
            'authors' => '',
            'child_of' => 0,
            'parent' => -1,
            'exclude_tree' => '',
            'number' => '',
            'offset' => 0,
            'post_type' => 'page',
            'post_status' => 'publish'
        ); 
        $pages = get_pages($args);
		$pageName = array();
		
		foreach($pages as $page){
			$pageName[] = array('page_url' => $page->post_name,'page_title' => $page->post_title);
		}

		$pagesInfo = array(
			"siteurl" => get_bloginfo('wpurl'),
			"pagelist" => $pageName
		);
		return json_encode($pagesInfo);
	}

	private function select_events($eventIds) {
		$eventIds = str_replace(' ', '', $eventIds);
		$eventIdArray = explode(",", $eventIds);
		
		$outArray = array();
		foreach ($this->eventDates as $event) {
			if(in_array($event['eventId'], $eventIdArray)) {
				$outArray[] = $event;
			}
		}
		$this->eventDates = $outArray;
	}
}