<?php
namespace Required;

class DynamicSyncSettings{
	protected $settings;
	private $table_name;

	public function loadDb(){
		global $wpdb;

		$this->table_name = $wpdb->prefix.'dynamicsync_settings';

		if($wpdb->get_var("SHOW TABLES LIKE '".$this->table_name."'") != $this->table_name) {
				//table not in database. Create new table
			$charset_collate = $wpdb->get_charset_collate();

			$sql = "CREATE TABLE $this->table_name (
				  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
				  `api_key` varchar(255) NOT NULL,
				  `regFormUrl` varchar(255) NOT NULL,
				  `eventIdField` varchar(255) NOT NULL,
				  `eventDateIdField` varchar(255) NOT NULL,
				  `eventNameField` varchar(255) NOT NULL,
				  `eventDateField` varchar(255) NOT NULL,
				  `customCSSField` text NOT NULL,
				  `eventDatesListCSSField` text NOT NULL,
				  `fullCalendarCSSField` text NOT NULL,
				  `tableCSSField` text NOT NULL,
				  `datesListCSSField` text NOT NULL,
				  `defaultResponsePage` text NOT NULL,
				  `registerResponseUrl` varchar(255) NOT NULL,
				  `thankYouUrl` text NOT NULL,
				  PRIMARY KEY (`id`)
				) $charset_collate;";
			require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
			dbDelta( $sql );

			$options_prefix = 'dynamicsync_';
		
			//GET SETTINGS
			parse_str( urldecode( get_option( $options_prefix.'calendar_settings' ) ), $dynamic_option );
				
			//GET API KEY
			if(isset($dynamic_option['api_key']))
				$api_key = $dynamic_option['api_key'];
			else
				$api_key = "";

			//GET FORM OPTIONS
			if(isset($dynamic_option['reg_form_url']))
				$reg_form_url = $dynamic_option['reg_form_url'];
			else
				$reg_form_url = "";

		    $wpdb->insert(
				$this->table_name,
				array(
					'api_key'				=> $api_key,
					'regFormUrl' 			=> $reg_form_url,
					'eventIdField' 			=> 'eId',
					'eventDateIdField'		=> 'edId',
					'eventNameField'		=> 'eN',
					'eventDateField'		=> 'eD',
					'customCSSField'		=> '',
					'eventDatesListCSSField'=> '.col-md-9 {
	display: inline-block;
	margin-bottom: 30px;
}
.col-md-2 {
	width: 240px;
	float: left;
	margin-right: 20px;
}
.col-md-7 {
	float: left;
	margin-bottom: 30px;
}
.ds-event-dates-container {
	overflow: hidden;
	margin-bottom: 25px;
	padding: 0px 0px 0px 20px;
}
.ds-event-dates-sold-out-text {
	font-weight: bold;
	color: red;
}',
					'fullCalendarCSSField'	=>  '.fc-content {
	white-space: normal !important;
}
.fc-low-warning {
	text-align: center;
	font-size: 1.2em;
}
.fc-sold-out {
	position: absolute;
	top: 10;
	left: 0;
}',
					'tableCSSField'			=> '',
					'datesListCSSField'		=> '',
					'defaultResponsePage'	=> '',
					'registerResponseUrl'	=> '',
					'thankYouUrl'			=> ''
				),
				array('%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s','%s')
			);


		}

		$this->loadSettings();
	}

	protected function loadSettings(){
		global $wpdb;
		$this->table_name = $wpdb->prefix.'dynamicsync_settings';
		$this->settings = $wpdb->get_row( "SELECT * FROM $this->table_name" );
	}

	public function updateSettings($apiKey,$formUrl){
		global $wpdb;
		
		$apiKey = $wpdb->_escape($apiKey);
		$formUrl = $wpdb->_escape($formUrl);

		$wpdb->update(
			$this->table_name,
			array(
				'api_key' => $apiKey,
				'regFormUrl' => $formUrl
			),
			array('id' => $this->settings->id),
			array('%s','%s')
		);
		$settings = $this->settings;
		$settings->api_key = $apiKey;
		$settings->regFormUrl = $formUrl;
		return $settings;
	}

	public function updateStyles($datesListCSSField,$eventDatesListCSSField,$fullCalendarCSSField,$tableCSSField,$customCSSField){
		global $wpdb;

		

		$wpdb->update(
			$this->table_name,
			array(
				'eventDatesListCSSField'=> $eventDatesListCSSField,
				'fullCalendarCSSField'	=> $fullCalendarCSSField,
				'tableCSSField' 		=> $tableCSSField,
				'datesListCSSField' 	=> $datesListCSSField,
				'customCSSField'		=> $customCSSField
			),
			array('id' => $this->settings->id),
			array('%s','%s','%s','%s','%s')
		);

		$settings = $this->settings;
		//$settings->customCSSField = $customCSSField;
		$settings->eventDatesListCSSField = $eventDatesListCSSField;
		$settings->fullCalendarCSSField = $fullCalendarCSSField;
		$settings->tableCSSField = $tableCSSField;
		$settings->datesListCSSField = $datesListCSSField;
		$settings->customCSSField = $customCSSField;
		return $settings;
	}
}